Struct rsmgp_sys::path::Path[][src]

pub struct Path { /* fields omitted */ }

Implementations

Fails if the current last vertex in the path is not part of the given edge or if there is not memory to expand the path.