Struct rsmgp_sys::memgraph::Memgraph [−][src]
pub struct Memgraph { /* fields omitted */ }Expand description
Main object to interact with Memgraph instance.
Implementations
pub fn new(
args: *const mgp_list,
graph: *const mgp_graph,
result: *mut mgp_result,
memory: *mut mgp_memory,
module: *mut mgp_module
) -> Memgraph[src]Creates a new object with all underlying data set to null. Used for the testing purposes.
Returns pointer to the object with all arguments passed to the procedure call.
Returns pointer to the object where results could be stored.
Returns pointer to the memory object for advanced memory control.
Returns pointer to the module object.
Creates a new result record.
Keep this object on the stack and add data that will be returned to Memgraph / client during/after the procedure call.
pub fn add_read_procedure(
&self,
proc_ptr: extern "C" fn(_: *const mgp_list, _: *const mgp_graph, _: *mut mgp_result, _: *mut mgp_memory),
name: &CStr,
result_fields: &[ResultFieldType<'_>]
) -> MgpResult<()>[src]
pub fn add_read_procedure(
&self,
proc_ptr: extern "C" fn(_: *const mgp_list, _: *const mgp_graph, _: *mut mgp_result, _: *mut mgp_memory),
name: &CStr,
result_fields: &[ResultFieldType<'_>]
) -> MgpResult<()>[src]Registers a new read procedure.
proc_ptr- Identifier of the top level C function that represents the procedure.name- A string that will be registered as a procedure name inside Memgraph instance.result_fields- An array of all ResultFieldTypes, each one define by FieldType.